summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/fm.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/fm.cpp')
-rw-r--r--src/devices/sound/fm.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/devices/sound/fm.cpp b/src/devices/sound/fm.cpp
index ee74c47fd97..cc21baa300c 100644
--- a/src/devices/sound/fm.cpp
+++ b/src/devices/sound/fm.cpp
@@ -3208,8 +3208,8 @@ UINT8 ym2608_read(void *chip,int a)
{
if(addr == 0x0f)
{
- F2608->device->logerror("YM2608 A/D convertion is accessed but not implemented !\n");
- ret = 0x80; /* 2's complement PCM data - result from A/D convertion */
+ F2608->device->logerror("YM2608 A/D conversion is accessed but not implemented !\n");
+ ret = 0x80; /* 2's complement PCM data - result from A/D conversion */
}
}
break;